@@ -1,4 +1,4 @@
-/*	$Id: vilter-attachment.c,v 1.44 2005/04/24 11:24:21 marc Exp $	*/
+/*	$Id: vilter-attachment.c,v 1.46 2005/12/27 08:16:29 mbalmer Exp $	*/
 
 /*
  * Copyright (c) 2004-2005 Marc Balmer <marc@msys.ch>.
@@ -198,7 +198,7 @@ analyze_header(struct be_data *priv, char *hdr, char *eom, int *name_len, struct
 		a = (struct arg *) malloc(sizeof(struct arg));
 
 		if (a == NULL) {
-			warnx("memory allocation failure");
+			warnx("attachment: memory allocation failure");
 			syslog(LOG_ERR, "attachment: unable to allocate memory for header");
 		}
 		bzero(a, sizeof(struct arg));
@@ -277,7 +277,7 @@ analyze_part(struct be_data *priv, struct part *p, char *eom, char *pattern, int
 #ifdef FUTURE			
 			if (base64) {
 				if (body < (eom - 3)) {	/* Need at least 3 bytes */
-					warnx("first two bytes of message body are %c %c", *body, *(body + 1));
+					warnx("attachment: first two bytes of message body are %c %c", *body, *(body + 1));
 					encoded[0] = find_base64(*body);
 					encoded[1] = find_base64(*(body + 1));
 					encoded[2] = find_base64(*(body + 2));
@@ -289,7 +289,7 @@ analyze_part(struct be_data *priv, struct part *p, char *eom, char *pattern, int
 					warnx("%c%c%c = %02x %02x", body[0], body[1], body[2], decoded[0], decoded[1]);
 
 					if (decoded[0] == 0xff && decoded[1] == 0xd8) {
-						warnx("found a jpeg image");
+						warnx("attachment: found a jpeg image");
 						p->skip = skip = 1;
 						strncpy(pattern, "JPEG IMAGE", patlen);
 					}
@@ -323,7 +323,7 @@ analyze_part(struct be_data *priv, struct part *p, char *eom, char *pattern, int
 							strlcpy(pattern, "content-type pattern: ", patlen);
 							strlcat(pattern, pat->pat, patlen);
 							if (verbose)
-								warnx("content-type pattern %s matches content type %s", pat->pat, ctype);
+								warnx("attachment: content-type pattern %s matches content type %s", pat->pat, ctype);
 							/* warnx("reason: %s", pattern); */
 						}
 					}
@@ -355,7 +355,7 @@ analyze_part(struct be_data *priv, struct part *p, char *eom, char *pattern, int
 							strlcpy(pattern, "filname pattern: ", patlen);
 							strlcat(pattern, pat->pat, patlen);
 							if (verbose)
-								warnx("filename pattern %s matches filename %s", pat->pat, filename);
+								warnx("attachment: filename pattern %s matches filename %s", pat->pat, filename);
 						}
 					}
 					free(filename);
@@ -493,7 +493,7 @@ vilter_scan(struct be_data *priv, char *fn, char *chroot, char *virus, int namel
 								p = NULL;
 							}
 						} else
-							syslog(LOG_ERR, "memory allocation error, not all message parts will be written");
+							syslog(LOG_ERR, "attachment: memory allocation error, not all message parts will be written");
 					}
 				}
 			}
@@ -516,7 +516,7 @@ vilter_scan(struct be_data *priv, char *fn, char *chroot, char *virus, int namel
 		skip += analyze_part(priv, p, eom, virus, namelen);
 
 	if (verbose)
-		warnx("will skip %d attachments", skip);
+		warnx("attachment: will skip %d attachments", skip);
 
 	if (skip > 0) {
 		tmpnam(newfn);
@@ -555,11 +555,7 @@ vilter_scan(struct be_data *priv, char *fn, char *chroot, char *virus, int namel
 		return SCAN_ERROR;
 	}
 
-	if (close(fd)) {
-		syslog(LOG_ERR, "attachment: can't close file");
-		/* memory leak */
-		return SCAN_ERROR;
-	}
+	close(fd);
 
 	while (!SLIST_EMPTY(&dhead)) {
 		p = SLIST_FIRST(&dhead);
