@@ -1,4 +1,4 @@
-/*	$Id: vilter-icap.c,v 1.22 2005/04/24 11:24:23 marc Exp $	*/
+/*	$Id: vilter-icap.c,v 1.26 2005/12/03 17:00:55 mbalmer Exp $	*/
 
 /*
  * Copyright (c) 2004-2005 Marc Balmer <marc@msys.ch>.
@@ -172,9 +172,9 @@ vilter_scan(struct be_data *priv, char *fn, char *chroot, char *virus, int namel
 	    "Host: %s:%d\r\n"
 	    "User-Agent: smtp-vilter-%s/icap\r\n"
 	    "Allow: 204\r\n"
-	    "Encapsulated: req-hdr=0, res-hdr=%d, res-body=%d\r\n\r\n",
+	    "Encapsulated: req-hdr=0, res-hdr=%ld, res-body=%ld\r\n\r\n",
 	    icap_uri, icap_query != NULL ? "?" : "", icap_query != NULL ? icap_query : "",
-	    icap_host, icap_port, VERSION, strlen(req_hdr), strlen(req_hdr) + strlen(res_hdr));
+	    icap_host, icap_port, VERSION, (long)strlen(req_hdr), (long)(strlen(req_hdr) + strlen(res_hdr)));
 
 	if (to_send(fd, buf, strlen(buf), 0, t) != strlen(buf)) {
 		syslog(LOG_ERR, "icap: send error");
@@ -194,7 +194,7 @@ vilter_scan(struct be_data *priv, char *fn, char *chroot, char *virus, int namel
 	fp = fopen(fn, "r");
 
 	if (fp == NULL)
-		warnx("can't open file");
+		warnx("icap: can't open file");
 
 	bzero(buf, sizeof(buf));
 
@@ -216,7 +216,7 @@ vilter_scan(struct be_data *priv, char *fn, char *chroot, char *virus, int namel
 		snprintf(req_hdr, sizeof(req_hdr), "\r\n");
 
 		if (to_send(fd, req_hdr, strlen(req_hdr), 0, t) != strlen(req_hdr)) {
-			syslog(LOG_ERR, "icap: crlf send error %d bytes", strlen(req_hdr));
+			syslog(LOG_ERR, "icap: crlf send error %ld bytes", (long)strlen(req_hdr));
 			goto response;
 		}
 	}
@@ -258,13 +258,13 @@ response:
 	if (verbose) {
 		switch (result) {
 		case SCAN_OK:
-			warnx("file contains no virus");
+			warnx("icap: file contains no virus");
 			break;
 		case SCAN_VIRUS:
-			warnx("found a virus: %s", virus);
+			warnx("icap: found a virus: %s", virus);
 			break;
 		case SCAN_ERROR:
-			warnx("error during virus scan");
+			warnx("icap: error during virus scan");
 			break;
 		}
 	}
