@@ -1,4 +1,4 @@
-/*	$Id: vilter-spamd.c,v 1.22 2005/04/24 11:24:23 marc Exp $	*/
+/*	$Id: vilter-spamd.c,v 1.24 2005/12/03 17:01:55 mbalmer Exp $	*/
 
 /*
  * Copyright (c) 2003-2005 Marc Balmer <marc@msys.ch>.
@@ -179,12 +179,12 @@ vilter_scan(struct be_data *priv, char *fn, char *chroot, double *score, double
 	fclose(fp);	
 
 	if (shutdown(fd, SHUT_WR)) {
-		syslog(LOG_ERR, "error shutting down writing on socket");
+		syslog(LOG_ERR, "spamd: error shutting down writing on socket");
 		close(fd);
 		return SCAN_ERROR;
 	}
 	if ((sp = fdsock(fd)) == NULL) {
-		syslog(LOG_ERR, "error buffering socker");
+		syslog(LOG_ERR, "spamd: error buffering socker");
 		close(fd);
 		return SCAN_ERROR;
 	}
