@@ -1,4 +1,4 @@
-/*	$Id: socket.c,v 1.14 2005/04/17 12:29:00 marc Exp $	*/
+/*	$Id: socket.c,v 1.16 2005/05/31 17:13:53 marc Exp $	*/
 
 /*
  * Copyright (c) 2003-2005 Marc Balmer <marc@msys.ch>.
@@ -58,7 +58,7 @@ to_recv(int s, void *buf, size_t len, int flags, struct timeval *timeout)
 }
 
 ssize_t
-to_send(int s, void *buf, size_t len, int flags, struct timeval *timeout)
+to_send(int s, const char *buf, size_t len, int flags, struct timeval *timeout)
 {
 	int	n;
 	int	sent;
@@ -141,4 +141,3 @@ sclose(SOCK *s)
 	close(s->sock);
 	free(s);
 }
-
