@@ -1,12 +1,11 @@
-/*	$Id: smtp-vilter.h,v 1.25 2005/04/24 10:07:56 marc Exp $	*/
+/*	$Id: smtp-vilter.h,v 1.44 2006/02/05 13:55:55 mbalmer Exp $	*/
 
 /*
- * Copyright (c) 2003-3005 Marc Balmer <marc@msys.ch>.
+ * Copyright (c) 2003-2006 Marc Balmer <marc@msys.ch>.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
+ * modification, are permitted provided that the following conditions are met:
  *
  * 1. Redistributions of source code must retain the above copyright
  *    notice, this list of conditions and the following disclaimer.
@@ -17,17 +16,16 @@
  * 3. The name of the author may not be used to endorse or promote products
  *    derived from this software without specific prior written permission.
  *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
- * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
- * COPYRIGHT HOLDERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
- * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
- * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
- * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
- * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
- * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
@@ -37,14 +35,25 @@
 #include <stdio.h>
 #include <unistd.h>
 
-#define	VERSION	"1.1.9"
+#define	VERSION	"1.2.7"
 
 #define MAJOR	5	/* Major and minor version number */
-#define MINOR	0	/* of shared libs (backends) */
+#define MINOR	1	/* of shared libs (backends) */
+
+#if __OpenBSD__
+#define ENABLE_PF
+#endif
+
+#if __FreeBSD__
+#include <sys/param.h>
+#if (__FreeBSD_version >= 600026)
+#define ENABLE_PF
+#endif
+#endif
 
 /*
-	The following values define reasons why an email might be rejected.
-*/
+ *	The following values define reasons why an email might be rejected.
+ */
 
 #define SCAN_OK		0	/* Message is acceptable */
 #define SCAN_VIRUS	1	/* Message contains a virus */
@@ -102,12 +111,20 @@ typedef struct _SOCK {
 	char	*pos;
 } SOCK;
 
+/* reactions */
+
+enum reactions {
+	REACTION_UNSET = -1,
+	REACTION_ADDTBL,
+	REACTION_DELTBL
+};
+
 extern int verbose;
 
 __BEGIN_DECLS
 extern SOCK *fdsock(int);
 extern ssize_t to_recv(int, void *, size_t, int, struct timeval *);
-extern ssize_t to_send(int, void *, size_t, int, struct timeval *);
+extern ssize_t to_send(int, const char *, size_t, int, struct timeval *);
 extern int to_readc(SOCK *, char *, struct timeval *);
 extern ssize_t to_readln(char *, int, SOCK *, struct timeval *);
 extern int *sputs(const char *, SOCK *, struct timeval *);
